/*
 * The MIT License
 *
 * Copyright 2012 Massive Dynamics.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package biz.massivedynamics.modger.formatter.message;

import biz.massivedynamics.modger.formatter.Formatter;
import biz.massivedynamics.modger.message.Message;
import java.text.SimpleDateFormat;
import java.util.Date;

/**
 * Formats a {@link Message} so that it shows the metadata and {@link String} message on a single line
 *
 * @author Cruz Bishop
 * @since 1.0.0.0
 */
public class SingleLineMessageFormatter extends Formatter<Message, Message> {
    
    /**
     * The {@link SimpleDateFormat} used for all {@link Message}s passed to this {@link Formatter}
     * 
     * @since 1.0.0.0
     */
    private SimpleDateFormat dateFormat = new SimpleDateFormat("d MMM yyyy hh:mm:ss a");

    /**
     * Formats the provided {@link Message}
     * 
     * @param message The {@link Message} to format
     * @return The formatted {@link Message}
     * @since 1.0.0.0
     */
    @Override
    public Message format(Message message) {
        
        //Get a new message
        Message newMessage = message.clone();
        
        //Set the message
        newMessage.setFormattedMessage(dateFormat.format(new Date()) 
                + ": [" + message.getType().name() + "] " 
                + message.getLogger().getName() + " - "
                + message.getRawMessage());
        
        //And return the message
        return newMessage;
        
    }
    
}
