/*
 * The MIT License
 *
 * Copyright 2012 Massive Dynamics.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package biz.massivedynamics.modger.formatter.throwable;

import biz.massivedynamics.modger.Modger;
import biz.massivedynamics.modger.formatter.Formatter;

/**
 * Formats a {@link Throwable} so that it displays the cause and {@link StackTraceElement}s
 *
 * @author Cruz Bishop
 * @since 1.0.0.0
 */
public class GenericThrowableFormatter extends Formatter<Throwable, String> {

    /**
     * Formats the raw {@link Throwable} and returns a {@link String}
     * 
     * @param rawData The raw data
     * @return The formatted string
     * @since 1.0.0.0
     */
    @Override
    public String format(Throwable rawData) {
        //Create a new string builder. Builders are faster than string addition
        StringBuilder builder = new StringBuilder();
        
        //Append the message
        builder.append(rawData.toString());
        
        //Loop through the stack trace
        for (StackTraceElement element : rawData.getStackTrace()) {
            //Append the trace element
            builder.append(Modger.getLineSeparator())
                    .append("\tat ")
                    .append(element.toString());
        }
        
        //Finish formatting, and return a string
        return builder.toString();
    }
    
}
