/*
 * The MIT License
 *
 * Copyright 2012 Massive Dynamics.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package biz.massivedynamics.modger.message.filter;

import biz.massivedynamics.modger.message.Message;

/**
 * An abstract class that is used to create {@link MessageFilter}s.
 * <p>
 *     A {@link MessageFilter} filters {@link Message}s, removing any that are not
 *     suitable for use.
 * </p>
 *
 * @author Cruz Bishop
 * @since 1.0.0.0
 */
public abstract class MessageFilter {
    
    /**
     * Checks to see if the specified {@link Message} is acceptable to parse
     * 
     * @param message The {@link Message} to check
     * @return True if acceptable, otherwise false
     * @since 1.0.0.0
     */
    public abstract boolean isAcceptable(Message message);
    
}
