/*
 * The MIT License
 *
 * Copyright 2012 Massive Dynamics.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package biz.massivedynamics.modger.message.filter.impl;

import biz.massivedynamics.modger.message.Message;
import biz.massivedynamics.modger.message.filter.MessageFilter;

/**
 * A {@link MessageFilter} that filters specified {@link biz.massivedynamics.modger.message.MessageType}s
 * 
 * @author Cruz Bishop
 * @since 1.0.0.0
 */
public class MessageTypeFilter extends MessageFilter {

    /**
     * Checks to see if the provided {@link Message} is acceptable
     * 
     * @param message The {@link Message} to filter
     * @return False if the {@link Message}'s type is to be filtered, otherwise true
     * @since 1.0.0.0
     */
    @Override
    public boolean isAcceptable(Message message) {
        return !message.getType().isFiltered(); //Just return false if the type is filtered!
    }
    
}
