/*
 * The MIT License
 *
 * Copyright 2012 Massive Dynamics.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package biz.massivedynamics.modger.message.handler;

import biz.massivedynamics.modger.message.Message;

/**
 * An abstract class that is used to define a {@link MessageHandler}
 * <p>
 *     A {@link MessageHandler} is passed {@link Message}s and {@link Throwable}s
 *     to handle. This may also include passing it on to a third party library.
 * </p>
 *
 * @author Cruz Bishop
 * @since 1.0.0.0
 */
public abstract class MessageHandler {
    
    /**
     * Submits a {@link Message} to be handled
     * 
     * @param message The {@link Message} to submit
     * @throws Exception Any {@link Exception}s that occur
     * @since 1.0.0.0
     */
    public abstract void submit(Message message) throws Exception;
    
    /**
     * Submits a {@link Message} and attached {@link Throwable} cause to the {@link MessageHandler}
     * 
     * @param message The {@link Message} to be submitted
     * @param cause The attached {@link Throwable} cause
     * @throws Exception Any {@link Exception}s that occur
     * @since 1.1.0.0
     */
    public abstract void submit(Message message, Throwable cause) throws Exception;
    
}
