/*
 * The MIT License
 *
 * Copyright 2012 Massive Dynamics.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package biz.massivedynamics.modger.message.handler.impl;

import biz.massivedynamics.modger.Modger;
import biz.massivedynamics.modger.message.Message;
import biz.massivedynamics.modger.message.handler.MessageHandler;
import java.io.DataOutputStream;

/**
 * A {@link MessageHandler} that writes to a {@link DataOutputStream}
 *
 * @author Cruz Bishop
 * @since 1.0.0.0
 */
public class DataOutputStreamMessageHandler extends MessageHandler {
    
    /**
     * Creates a new {@link DataOutputStreamMessageHandler}
     * 
     * @param stream The {@link DataOutputStream to use}
     * @since 1.0.0.0
     */
    public DataOutputStreamMessageHandler(DataOutputStream stream) {
        this.stream = stream;
    }
    
    /**
     * The {@link DataOutputStream} to be used
     * 
     * @since 1.0.0.0
     */
    private DataOutputStream stream;
    
    /**
     * Gets the {@link DataOutputStream} to be used
     * 
     * @return The {@link DataOutputStream} to be used
     * @since 1.0.0.0
     */
    public DataOutputStream getStream() {
        return this.stream;
    }
    
    /**
     * Sets the {@link DataOutputStream} to be used
     * 
     * @param stream The stream to use
     * @since 1.0.0.0
     */
    public void setStream(DataOutputStream stream) {
        this.stream = stream;
    }

    /**
     * Submits the specified {@link Message}
     * 
     * @param message The {@link Message} to submit
     * @throws Exception Any {@link Exception}s that occur
     * @since 1.0.0.0
     */
    @Override
    public void submit(Message message) throws Exception {
        this.stream.writeUTF(message.getFormattedMessage());
    }

    /**
     * Submits a {@link Message} and attached {@link Throwable} cause
     * 
     * @param message The {@link Message} to submit
     * @param cause The attached {@link Throwable} cause
     * @throws Exception Any {@link Exception}s that occur
     * @since 1.0.0.0
     */
    @Override
    public void submit(Message message, Throwable cause) throws Exception {
        this.stream.writeUTF(message.getFormattedMessage() + Modger.getLineSeparator() + message.getLogger().getThrowableFormatter().format(cause));
    }
    
}
