/*
 * The MIT License
 *
 * Copyright 2012 Massive Dynamics.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package biz.massivedynamics.modger.message.handler.impl;

import biz.massivedynamics.modger.Modger;
import biz.massivedynamics.modger.message.Message;
import biz.massivedynamics.modger.message.MessageType;
import biz.massivedynamics.modger.message.handler.MessageHandler;
import java.io.OutputStream;

/**
 * A {@link MessageHandler} that prints to the relevant system {@link OutputStream}
 *
 * @author Cruz Bishop
 * @since 1.0.0.0
 */
public class SystemOutputMessageHandler extends MessageHandler {

    /**
     * Submits a {@link Message} for printing
     * 
     * @param message The {@link Message}
     * @since 1.0.0.0
     */
    @Override
    public void submit(Message message) {
        if (message.getType() == MessageType.WARNING || message.getType() == MessageType.ERROR) {
            System.err.println(message.getFormattedMessage());
        } else {
            System.out.println(message.getFormattedMessage());
        }
    }

    /**
     * Submits a {@link Message} and attached {@link Throwable} cause
     * 
     * @param message The {@link Message}
     * @param cause The {@link Throwable} cause
     * @throws Exception Any {@link Exception}s that occur
     * @since 1.1.0.0
     */
    @Override
    public void submit(Message message, Throwable cause) throws Exception {
        if (message.getType() == MessageType.WARNING || message.getType() == MessageType.ERROR) {
            System.err.println(message.getFormattedMessage() + Modger.getLineSeparator() + message.getLogger().getThrowableFormatter().format(cause));
        } else {
            System.out.println(message.getFormattedMessage() + Modger.getLineSeparator() + message.getLogger().getThrowableFormatter().format(cause));
        }
    }
    
}
